summaryrefslogtreecommitdiff
path: root/include/dlt/dlt_filetransfer.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/dlt/dlt_filetransfer.h')
-rw-r--r--include/dlt/dlt_filetransfer.h32
1 files changed, 22 insertions, 10 deletions
diff --git a/include/dlt/dlt_filetransfer.h b/include/dlt/dlt_filetransfer.h
index 077e3f0..44436e7 100644
--- a/include/dlt/dlt_filetransfer.h
+++ b/include/dlt/dlt_filetransfer.h
@@ -82,16 +82,28 @@ extern int dlt_user_log_file_packagesCount(DltContext *fileContext, const char *
extern int dlt_user_log_file_infoAbout(DltContext *fileContext, const char *filename);
-//!Transfer the head of the file as a dlt logs.
-/**The head of the file must be logged to dlt because the head contains inforamtion about the file serial number,
- * the file name, the file size, package number the file have and the buffer size.
- * All these informations are needed from the plugin of the dlt viewer.
- * See the Mainpages.c for more informations.
- * @param fileContext Specific context to log the file to dlt
- * @param filename Absolute file path
- * @return Returns 0 if everything was okey. If there was a failure value < 0 will be returned.
- */
-extern int dlt_user_log_file_header(DltContext *fileContext, const char *filename);
+ //!Transfer the head of the file as a dlt logs.
+ /**The head of the file must be logged to dlt because the head contains inforamtion about the file serial number,
+ * the file name, the file size, package number the file have and the buffer size.
+ * All these informations are needed from the plugin of the dlt viewer.
+ * See the Mainpages.c for more informations.
+ * @param fileContext Specific context to log the file to dlt
+ * @param filename Absolute file path
+ * @param alias Alias for the file. An alternative name to show in the receiving end
+ * @return Returns 0 if everything was okey. If there was a failure value < 0 will be returned.
+ */
+ extern int dlt_user_log_file_header_alias(DltContext *fileContext, const char *filename, const char *alias);
+
+ //!Transfer the head of the file as a dlt logs.
+ /**The head of the file must be logged to dlt because the head contains inforamtion about the file serial number,
+ * the file name, the file size, package number the file have and the buffer size.
+ * All these informations are needed from the plugin of the dlt viewer.
+ * See the Mainpages.c for more informations.
+ * @param fileContext Specific context to log the file to dlt
+ * @param filename Absolute file path
+ * @return Returns 0 if everything was okey. If there was a failure value < 0 will be returned.
+ */
+ extern int dlt_user_log_file_header(DltContext *fileContext, const char *filename);
//!Transfer the content data of a file.